import React, { FC } from 'react';
import { Pressable, Animated, StyleProp } from 'react-native';

interface Props {
  onClick?: () => void;
  disabled?: boolean;
  style?: StyleProp<any> | StyleProp<any>[];
  children: JSX.Element | JSX.Element[];
}

export const TouchableOpacityButtonWrapper: FC<Props> = ({
  onClick,
  disabled,
  style,
  children,
}) => {
  const animated = new Animated.Value(1);
  const fadeIn = () => {
    Animated.timing(animated, {
      toValue: 0.2,
      duration: 50,
      useNativeDriver: true,
    }).start();
  };
  const fadeOut = () => {
    Animated.timing(animated, {
      toValue: 1,
      duration: 200,
      useNativeDriver: true,
    }).start();
  };

  return (
    <Pressable
      onPressIn={fadeIn}
      onPressOut={fadeOut}
      onPress={onClick}
      disabled={disabled}
    >
      <Animated.View style={[{ opacity: animated }].concat(style)}>
        {children}
      </Animated.View>
    </Pressable>
  );
};
