import React, { FC } from 'react';
import { Dimensions, TouchableOpacity, View } from 'react-native';
import { CenterModalNavigationWrapperModel } from '../modalWrapperModels';
import { styles } from './styles';
import { spacingSizes } from '../../../../constants';

const windowHeight = Dimensions.get('window').height;
const windowWidth = Dimensions.get('window').width;

export const CenterModalNavigationWrapper: FC<CenterModalNavigationWrapperModel> = ({
  onCloseModal,
  outsideCloseEnabled = true,
  modalHeight,
  modalWidth,
  backgroundColor= '#00000066',
  children,
}) => {
  const defaultModalHeight: number = typeof modalHeight === 'string'
    ? windowHeight * (parseFloat(modalHeight)/100)
    : modalHeight;

  const defaultModalWidth: number = typeof modalWidth === 'string'
    ? windowWidth * (parseFloat(modalWidth)/100)
    : modalWidth;

  const maxWidth = windowWidth - (spacingSizes.medium * 2);
  const maxHeight = windowHeight - (spacingSizes.large * 2);

  const width = defaultModalWidth > maxWidth ? maxWidth : defaultModalWidth;
  const height = defaultModalHeight > maxHeight ? maxHeight : defaultModalHeight;

  const onClose = () => {
    onCloseModal?.();
  };

  return (
    <View style={[styles.centerModalWrapper, { backgroundColor, height: windowHeight,  width: windowWidth }]}>
      <TouchableOpacity style={{ height: windowHeight }} onPress={() => outsideCloseEnabled && onClose()} />
      <View
        style={
          [
            {
              height: height,
              width: width,
              transform: [{ translateY: -height/2 }, { translateX: -width/2 }],
            },
            styles.centerModalWrapperContent,
          ]}
      >
        {children}
      </View>
    </View>
  );
};
