import React, { FC } from 'react';
import { ScrollView, View } from 'react-native';
import { ListItemsModel } from '../listItemsModels';
import { LabelMediumText } from '../../../atoms';
import { styles } from './styles';

export const TwoColumnsListItemsWrapper: FC<ListItemsModel> = ({
  listItemsValues,
  ItemComponent,
  title,
  onClick,
}) => {
  return (
    <ScrollView>
      {title &&
        <View style={styles.twoColumnsListItemsWrapperTitle}>
          <LabelMediumText color={styles.twoColumnsListItemsWrapperTitle.color}>{title}</LabelMediumText>
        </View>
      }
      <View style={styles.twoColumnsListItemsWrapper}>
        {ItemComponent && listItemsValues?.map((item, key) => {
          const isPairColumn = key%2 === 0;
          return (
            <View
              key={key}
              style={[
                styles.twoColumnsListItemsWrapperColumn,
                isPairColumn ? styles.twoColumnsListItemsWrapperPairColumn : styles.twoColumnsListItemsWrapperOddColumn,
              ]}
            >
              {item?.Component &&
                <item.Component
                  key={item?.id}
                  Icon={item?.Icon}
                  LeftIcon={item?.LeftIcon}
                  RightIcon={item?.RightIcon}
                  text={item?.text}
                  description={item?.description}
                  onClick={() => onClick && onClick(item?.id)}
                  imageURL={item?.imageURL}
                />
              }
              {!item?.Component &&
                <ItemComponent
                  key={item?.id}
                  Icon={item?.Icon}
                  LeftIcon={item?.LeftIcon}
                  RightIcon={item?.RightIcon}
                  text={item?.text}
                  description={item?.description}
                  onClick={() => onClick && onClick(item?.id)}
                  imageURL={item?.imageURL}
                />
              }
            </View>
          );
        })}
      </View>
    </ScrollView>
  );
};
