import React, { FC } from 'react';
import { View } from 'react-native';
import { Body2RegularText,
  DoorClosedIcon,
  DoorOpenIcon,
  LabelMediumText } from '../../../atoms';
import { DragThumb, SpinnerThumb } from '../../../atoms/thumbs';
import { BooleanSlider } from '../../../molecules';
import { BinaryDoorWidgetDetailModel } from '../widgetDetailModels';
import { styles } from './styles';

const stateTypes = {
  OFF: 'OFF',
  ON: 'ON',
};

const stateToNumber = {
  [stateTypes.ON]: 1,
  [stateTypes.OFF]: 0,
};

const actionTypes = {
  UNLOCK: 1,
};

export const BinaryDoorWidgetDetail: FC<BinaryDoorWidgetDetailModel> = ({
  title,
  subtitle,
  loadingInfoTextOptions,
  defaultValue = stateTypes.OFF,
  id,
  onUpdateData,
  loading = false,
}) => {
  const loadingInfoText = loadingInfoTextOptions?.option1;
  const onChange = (value: number) => {
    onUpdateData &&
      value === actionTypes.UNLOCK && onUpdateData({ id, value: stateTypes.ON });
  };

  return (
    <View>
      <View style={styles.binaryDoorInfoTextBlock}>
        <LabelMediumText>{title}</LabelMediumText>
        {!loading && <Body2RegularText color={styles.binaryDoorInfoTextBlock.color}>{subtitle}</Body2RegularText>}
        {loading &&
          <Body2RegularText color={styles.binaryDoorInfoTextBlock.color}>{loadingInfoText}</Body2RegularText>}
      </View>
      <BooleanSlider
        defaultValue={stateToNumber[defaultValue]}
        ThumbComponent={loading ? SpinnerThumb : DragThumb}
        IconLeft={DoorClosedIcon}
        IconRight={DoorOpenIcon}
        onStateChange={onChange}
      />
    </View>
  );
};
