import React, { FC, useEffect } from 'react';
import { View } from 'react-native';
import { GradualShutterWithSlatsWidgetDetailModel } from '../../widgetDetailModels';
import { ShutterControlPanel } from '../components/shutterControlPanel';
import { ShutterQuickActions } from '../components/shutterQuickActions';
import { ShutterAction, SlatsAction } from '../components/shutterModels';
import { useShutter } from '../hooks/useShutter';
import { useSlats } from '../hooks/useSlats';
import { SlatsControlPanel } from '../components/slatsControlPanel';

const getNumberFromValue = (value: string) => Number(value);
const getStringFromActionResult = (result: number) => String(result);

export const GradualShutterWithSlatsWidgetDetail: FC<GradualShutterWithSlatsWidgetDetailModel> = (
  { shutterConfig, slatsConfig }) => {
  const {
    shutterId,
    shutterValue = '0',
    shutterTitle,
    quickActionsTitle,
    quickActionButtonsTextOptions,
    shutterControlPanelTitle,
    shutterInfoTextOptions,
    shutterLoadingInfoTextOptions,
    onChangeShutterValue,
    isShutterLoading,
  } = shutterConfig;
  const {
    slatsId,
    slatsValue = '0',
    slatsControlPanelTitle,
    onChangeSlatsValue,
    isSlatsLoading,
  } = slatsConfig;

  const { shutterOutputValue, onShutterAction, shutterOngoingAction } = useShutter(getNumberFromValue(shutterValue));
  const { fixedSlatsValue, setSlatsValue, onSlatsAction } = useSlats();
  const buttonOneText = quickActionButtonsTextOptions?.open;
  const buttonTwoText = quickActionButtonsTextOptions?.close;

  const handleChangeShutterValue = (action: ShutterAction) => {
    const resultAfterAction = onShutterAction(action);
    onChangeShutterValue?.({ id: shutterId, value: getStringFromActionResult(resultAfterAction) });
  };

  const handleChangeSlatsValue = (action: SlatsAction) => {
    const resultAfterAction = onSlatsAction(getNumberFromValue(slatsValue), action);
    slatsValue && onChangeSlatsValue?.({ id: slatsId, value: getStringFromActionResult(resultAfterAction) });
  };

  useEffect(() => {
    setSlatsValue(getNumberFromValue(slatsValue));
  }, [slatsValue]);

  return (
    <View>
      <ShutterQuickActions
        title={quickActionsTitle}
        value={shutterOutputValue}
        buttonOneText={buttonOneText}
        buttonTwoText={buttonTwoText}
        onClick={handleChangeShutterValue}
        loading={isShutterLoading}
      />
      <ShutterControlPanel
        title={shutterControlPanelTitle}
        widgetName={shutterTitle}
        widgetStateInfoOptions={shutterInfoTextOptions}
        loadingInfoTextOptions={shutterLoadingInfoTextOptions}
        value={shutterOutputValue}
        ongoingAction={shutterOngoingAction}
        onClick={handleChangeShutterValue}
        loading={isShutterLoading}
      />
      <SlatsControlPanel
        title={slatsControlPanelTitle}
        value={fixedSlatsValue}
        onClick={handleChangeSlatsValue}
        loading={isSlatsLoading}
      />
    </View>
  );
};
