import React, { FC, useEffect, useState } from 'react';
import { View } from 'react-native';
import { Body2RegularText, LabelMediumText, SwitchLarge } from '../../../atoms';
import { SwitchWidgetDetailModel } from '../widgetDetailModels';
import { styles } from './styles';

const stateTypes = {
  OFF: 'OFF',
  ON: 'ON',
};

const valueFromBoolean = {
  true: stateTypes.ON,
  false: stateTypes.OFF,
};

const stateToBooleanValue = {
  [stateTypes.ON]: true,
  [stateTypes.OFF]: false,
};

export const SwitchWidgetDetail: FC<SwitchWidgetDetailModel> = ({
  title,
  subtitle,
  loadingInfoTextOptions,
  value = stateTypes.OFF,
  id,
  onUpdateData,
  loading: isLoading = false,
}) => {
  const [isEnabled, setIsEnabled] = useState<boolean>(stateToBooleanValue[value]);
  const switchingOnInfoText = loadingInfoTextOptions?.option1;
  const switchingOffInfoText = loadingInfoTextOptions?.option2;

  const onChange = () => {
    const booleanValue = !stateToBooleanValue[value];
    setIsEnabled(booleanValue);
    const updatedValue = valueFromBoolean[`${booleanValue}`];
    onUpdateData && onUpdateData ({ id, value: updatedValue });
  };

  useEffect(() => {
    setIsEnabled(stateToBooleanValue[value]);
  }, [value]);

  return (
    <View style={styles.switchWidgetDetail}>
      <View>
        <LabelMediumText>{title}</LabelMediumText>
        {!isLoading &&
            <Body2RegularText color={styles.switchWidgetDetail.color}>
              {value === stateTypes.ON ? subtitle?.on : subtitle?.off}
            </Body2RegularText>
        }
        {isLoading && isEnabled &&
          <Body2RegularText color={styles.switchWidgetDetail.color}>{switchingOnInfoText}</Body2RegularText>}
        {isLoading && !isEnabled &&
          <Body2RegularText color={styles.switchWidgetDetail.color}>{switchingOffInfoText}</Body2RegularText>}
      </View>
      <SwitchLarge
        disabled={isLoading}
        loading={isLoading}
        onValueChange={onChange}
        value={isEnabled}
      />
    </View>
  );
};
